package com.ruoyi.model.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.model.domain.AppletOutDate;

/**
 * 不接单日期Service接口
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
public interface IAppletOutDateService extends IService<AppletOutDate>
{
    /**
     * 查询不接单日期
     * 
     * @param id 不接单日期主键
     * @return 不接单日期
     */
    public AppletOutDate selectAppletOutDateById(Long id);

    /**
     * 查询不接单日期列表
     * 
     * @param appletOutDate 不接单日期
     * @return 不接单日期集合
     */
    public List<AppletOutDate> selectAppletOutDateList(AppletOutDate appletOutDate);

    /**
     * 新增不接单日期
     * 
     * @param appletOutDate 不接单日期
     * @return 结果
     */
    public int insertAppletOutDate(AppletOutDate appletOutDate);

    /**
     * 修改不接单日期
     * 
     * @param appletOutDate 不接单日期
     * @return 结果
     */
    public int updateAppletOutDate(AppletOutDate appletOutDate);

    /**
     * 批量删除不接单日期
     * 
     * @param ids 需要删除的不接单日期主键集合
     * @return 结果
     */
    public int deleteAppletOutDateByIds(Long[] ids);
    public int deleteAppletOutDateByIdList(Long addressId);

    /**
     * 删除不接单日期信息
     * 
     * @param id 不接单日期主键
     * @return 结果
     */
    public int deleteAppletOutDateById(Long id);
}
